@@ -1,4 +1,4 @@
-{-# LANGUAGE CPP, ForeignFunctionInterface #-}
+{-# LANGUAGE CPP #-}
 
 -- |
 -- Module      : Network.Socket.ByteString.Internal
@@ -16,25 +16,19 @@ module Network.Socket.ByteString.Internal
     , c_writev
     , c_sendmsg
 #endif
-    , waitWhen0
     ) where
 
+import GHC.IO.Exception (IOErrorType(..))
 import System.IO.Error (ioeSetErrorString, mkIOError)
 
 #if !defined(mingw32_HOST_OS)
-import Foreign.C.Types (CInt(..))
 import System.Posix.Types (CSsize(..))
-import Foreign.Ptr (Ptr)
 
+import Network.Socket.Imports
 import Network.Socket.ByteString.IOVec (IOVec)
 import Network.Socket.ByteString.MsgHdr (MsgHdr)
 #endif
 
-import Control.Concurrent (threadWaitWrite, rtsSupportsBoundThreads)
-import Control.Monad (when)
-import GHC.IO.Exception (IOErrorType(..))
-import Network.Socket.Types
-
 mkInvalidRecvArgError :: String -> IOError
 mkInvalidRecvArgError loc = ioeSetErrorString (mkIOError
                                     InvalidArgument
@@ -47,9 +41,3 @@ foreign import ccall unsafe "writev"
 foreign import ccall unsafe "sendmsg"
   c_sendmsg :: CInt -> Ptr MsgHdr -> CInt -> IO CSsize
 #endif
-
-waitWhen0 :: Int -> Socket -> IO ()
-waitWhen0 0 s = when rtsSupportsBoundThreads $ do
-  let fd = fromIntegral $ fdSocket s
-  threadWaitWrite fd
-waitWhen0 _ _ = return ()
