@@ -9,10 +9,6 @@
 
 #include "HsNetDef.h"
 
-#ifdef NEED_WINVER
-# define WINVER 0x0501
-#endif
-
 #ifndef INLINE
 # if defined(_MSC_VER)
 #  define INLINE extern __inline
@@ -23,30 +19,14 @@
 # endif
 #endif
 
-#ifdef HAVE_GETADDRINFO
-# define IPV6_SOCKET_SUPPORT 1
-#else
-# undef IPV6_SOCKET_SUPPORT
+#define _GNU_SOURCE 1 /* for struct ucred on Linux */
+
+#ifdef _WIN32
+# include <winsock2.h>
+# include <ws2tcpip.h>
+# define IPV6_V6ONLY 27
 #endif
 
-#if defined(HAVE_WINSOCK2_H)
-#include <winsock2.h>
-# ifdef HAVE_WS2TCPIP_H
-#  include <ws2tcpip.h>
-// fix for MingW not defining IPV6_V6ONLY
-#  define IPV6_V6ONLY 27
-# endif
-
-extern int   initWinSock ();
-extern const char* getWSErrorDescr(int err);
-extern void* newAcceptParams(int sock,
-			     int sz,
-			     void* sockaddr);
-extern int   acceptNewSock(void* d);
-extern int   acceptDoProc(void* param);
-
-#else
-
 #ifdef HAVE_LIMITS_H
 # include <limits.h>
 #endif
@@ -68,14 +48,12 @@ extern int   acceptDoProc(void* param);
 #ifdef HAVE_SYS_SOCKET_H
 # include <sys/socket.h>
 #endif
-#ifdef HAVE_LINUX_TCP_H
-# include <linux/tcp.h>
-#elif HAVE_NETINET_TCP_H
-# include <netinet/tcp.h>
-#endif
 #ifdef HAVE_NETINET_IN_H
 # include <netinet/in.h>
 #endif
+#ifdef HAVE_NETINET_TCP_H
+# include <netinet/tcp.h>
+#endif
 #ifdef HAVE_SYS_UN_H
 # include <sys/un.h>
 #endif
@@ -85,34 +63,32 @@ extern int   acceptDoProc(void* param);
 #ifdef HAVE_NETDB_H
 #include <netdb.h>
 #endif
-#ifdef HAVE_LINUX_CAN_H
-# include <linux/can.h>
-# define CAN_SOCKET_SUPPORT 1
-#endif
-#ifdef HAVE_NET_IF
+#ifdef HAVE_NET_IF_H
 # include <net/if.h>
 #endif
-
-#ifdef HAVE_BSD_SENDFILE
-#include <sys/uio.h>
-#endif
-#ifdef HAVE_LINUX_SENDFILE
-#if !defined(__USE_FILE_OFFSET64)
-#include <sys/sendfile.h>
-#endif
+#ifdef HAVE_NETIOAPI_H
+# include <netioapi.h>
 #endif
 
+#ifdef _WIN32
+extern int   initWinSock ();
+extern const char* getWSErrorDescr(int err);
+extern void* newAcceptParams(int sock,
+			     int sz,
+			     void* sockaddr);
+extern int   acceptNewSock(void* d);
+extern int   acceptDoProc(void* param);
+#else  /* _WIN32 */
 extern int
 sendFd(int sock, int outfd);
 
 extern int
 recvFd(int sock);
-
-#endif /* HAVE_WINSOCK2_H */
+#endif /* _WIN32 */
 
 INLINE char *
 hsnet_inet_ntoa(
-#if defined(HAVE_WINSOCK2_H)
+#if defined(_WIN32)
              u_long addr
 #elif defined(HAVE_IN_ADDR_T)
              in_addr_t addr
@@ -128,10 +104,9 @@ hsnet_inet_ntoa(
     return inet_ntoa(a);
 }
 
-#ifdef HAVE_GETADDRINFO
 INLINE int
 hsnet_getnameinfo(const struct sockaddr* a,socklen_t b, char* c,
-# if defined(HAVE_WINSOCK2_H)
+# if defined(_WIN32)
                   DWORD d, char* e, DWORD f, int g)
 # else
                   socklen_t d, char* e, socklen_t f, int g)
@@ -152,13 +127,12 @@ hsnet_freeaddrinfo(struct addrinfo *ai)
 {
     freeaddrinfo(ai);
 }
-#endif
 
-#if !defined(IOV_MAX)
+#ifndef IOV_MAX
 # define IOV_MAX 1024
 #endif
 
-#if !defined(SOCK_NONBLOCK) // Missing define in Bionic libc (Android)
+#ifndef SOCK_NONBLOCK // Missing define in Bionic libc (Android)
 # define SOCK_NONBLOCK O_NONBLOCK
 #endif
 
